@@ -18,9 +18,8 @@ from django_fabfile.instances import (attach_snapshot, create_temp_inst,
                                       get_avail_dev, get_vol_dev, mount_volume)
 from django_fabfile.utils import (
     Config, StateNotChangedError, add_tags, config_temp_ssh,
-    get_descr_attr, get_inst_by_id, get_region_conn,
-    get_snap_time, get_snap_vol, get_snap_device,
-    wait_for, wait_for_sudo)
+    get_descr_attr, get_inst_by_id, get_region_conn, get_snap_device,
+    get_snap_time, get_snap_vol, timestamp, wait_for, wait_for_sudo)
 
 
 config = Config()
@@ -30,9 +29,6 @@ env.update({'user': username, 'disable_known_hosts': True})
 logger = logging.getLogger(__name__)
 
 
-_now = lambda: datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%S')
-
-
 def create_snapshot(vol, description='', tags=None, synchronously=True):
     """Return new snapshot for the volume.
 
@@ -59,7 +55,7 @@ def create_snapshot(vol, description='', tags=None, synchronously=True):
             'Type': inst.instance_type,
             'Arch': inst.architecture,
             'Root_dev_name': inst.root_device_name,
-            'Time': _now(),
+            'Time': timestamp(),
             })
 
     def initiate_snapshot():
