@@ -290,15 +290,21 @@ def config_temp_ssh(conn):
 
 
 def new_security_group(region, name=None, description=None):
-    return get_region_conn(region.name).create_security_group(
+    """Create Security Groups with SSH access."""
+    s_g = get_region_conn(region.name).create_security_group(
         name or 'Created on {0}'.format(timestamp()),
         description or 'Created for using with specific instance')
+    s_g.authorize('tcp', 22, 22, '0.0.0.0/0')
+    return s_g
 
 
 @task
-def cleanup_security_groups(dry_run=False):
+def cleanup_security_groups(delete=False):
     """Delete unused AWS Security Groups.
 
+    :type delete: boolean
+    :param delete: notify only by default.
+
     If security group with the same name is used at least in one region,
     it is treated as used."""
     groups = defaultdict(lambda: {})
@@ -311,9 +317,9 @@ def cleanup_security_groups(dry_run=False):
         if any(s_g.instances() for s_g in groups[grp].values()):
             del groups[grp]     # Security Group is used.
     for grp in sorted(groups):
-        if dry_run:
-            msg = '"SecurityGroup:{grp}" should be removed from {regs}'
-            logger.info(msg.format(grp=grp, regs=groups[grp].keys()))
-        else:
+        if delete:
             for reg in groups[grp]:
                 groups[grp][reg].delete()
+        else:
+            msg = '"SecurityGroup:{grp}" should be removed from {regs}'
+            logger.info(msg.format(grp=grp, regs=groups[grp].keys()))
